@@ -29,10 +29,11 @@ $user || &errordie("User $ARGV[0] does not exist");
 $| = 1;
 if ($askold) {
 	# Ask for the old password
+	&foreign_require("useradmin");
 	print "(current) UNIX password: ";
 	$old = <STDIN>;
 	$old =~ s/\r|\n//g;
-	crypt($old, $user->{'pass'}) eq $user->{'pass'} ||
+	&useradmin::validate_password($old, $user->{'pass'}) ||
 		&errordie("Old password is incorrect");
 	}
 
@@ -46,7 +47,7 @@ $again =~ s/\r|\n//g;
 $pass eq $again || &errordie("Passwords don't match");
 
 # Check password sanity
-$err = &useradmin::check_password_restrictions($pass, $ARGV[0]);
+$err = &useradmin::check_password_restrictions($pass, $ARGV[0], $user);
 &errordie($err) if ($err);
 
 # Do the change!
